@@ -60,9 +60,13 @@ class Maintenance:
             module = importlib.import_module(name)
             try:
                 repo = Repo(os.path.dirname(os.path.dirname(module.__file__)))
-                hash_ = repo.head.reference.commit.hexsha
             except InvalidGitRepositoryError:
                 hash_ = "Not a repo"
+            else:
+                try:
+                    hash_ = repo.head.reference.commit.hexsha
+                except (ValueError, TypeError):
+                    hash_ = "Error while resolving sha"
             if hasattr(module, "__version__"):
                 version = module.__version__
             else:
